@@ -3,5 +3,5 @@
     library.dynam("spatgraphs", pkg, lib)
     v <- read.dcf(file=system.file("DESCRIPTION", package="spatgraphs"),
                   fields="Version")
-    cat(paste("\nLoaded Spatial graph functions (\"spatgraphs\") ", v, "\n"))
+    cat(paste("Loaded Spatial graph functions (\"spatgraphs\") ", v, "\n"))
 }
