@@ -21,14 +21,14 @@ runif3d<-function(n=c(10), window=list(x=c(0,1),y=c(0,1),z=c(0,1)))
 }
 
 ##
-spin3d<-function(sec = 10, theta=0, rotspeed = 1, ang = 0, zoom = 1, fov = 60, capture=FALSE, cap.prefix="temp",j=100000) 
-{
-	start <- proc.time()[3]
-	while ((i <- rotspeed * 36 * (proc.time()[3] - start)) < 36 * sec * rotspeed) 
-	{
-		rgl.viewpoint(i+theta, ang, zoom = zoom, fov = fov)
-		j<-j+1
-		if(capture) snapshot3d(file=paste(cap.prefix,substr(as.character(j),2,6),".png",sep=""), top=TRUE)
-	}
-	c(theta=theta+i,j=j)
-}
+#spin3d<-function(sec = 10, theta=0, rotspeed = 1, ang = 0, zoom = 1, fov = 60, capture=FALSE, cap.prefix="temp",j=100000) 
+#{
+#	start <- proc.time()[3]
+#	while ((i <- rotspeed * 36 * (proc.time()[3] - start)) < 36 * sec * rotspeed) 
+#	{
+#		rgl.viewpoint(i+theta, ang, zoom = zoom, fov = fov)
+#		j<-j+1
+#		if(capture) snapshot3d(file=paste(cap.prefix,substr(as.character(j),2,6),".png",sep=""), top=TRUE)
+#	}
+#	c(theta=theta+i,j=j)
+#}
